@@ -4,6 +4,13 @@ import copy
 from sklearn.metrics import cohen_kappa_score
 
 
+def set_all_seeds(seed):
+    import numpy as np
+    import torch
+
+    torch.manual_seed(seed)
+    np.random.seed(seed)
+
 def count_annotations_project(project):
     cnt = 0
     for doc in project['documents']:
@@ -192,7 +199,7 @@ def check_differences(data_path, cat, cntx_size=30, min_acc=0.2, ignore_already_
             print("Starting: {} / {}".format(did, len(project['documents'])))
             text = doc['text']
 
-            if not doc.get('_verified', False) or ignore_already_done:
+            if not doc.get('_verified', False) or ignore_already_done or only_saved:
                 # Get annotations with medcat
                 s_doc = cat(text)
 
